#!/bin/bash
# opens url in existing konqueror/mozilla
# if no k/m is running a new process will be spawned
# if mozilla is chosen, the url will be opened in the last active window
# if konqueror is chosen the url will be opened in a new window... the pid
#  is written to a tmp-file and the next time this script is called it will try
#  to open the url in this pid's konqueror

DEFAULTBROWSER="k"

open_konq()
{
  STARTED="0"
  CURRENTUSER=`whoami`
  PIDFILE="/tmp/tkclient.pid"
  echo "using konqueror"
  if [ -z "`which konqueror`" ]
  then
    echo "Konqueror binary has to be in \$PATH"
    exit 1
  fi
  echo "checking if Konqueror still exists..."

  if [ -e ${PIDFILE}-${CURRENTUSER} ]
  then
    echo PID-File exists
    dcop konqueror-`cat ${PIDFILE}-$CURRENTUSER` konqueror-mainwindow\#1 openURL $1
    if [ $? -eq 0 ]
    then
      echo ">opened in existing window"
      exit 0
    fi
  fi

  echo ">starting new konq"

  konqueror &
  LASTPID=$!
  echo $LASTPID > ${PIDFILE}-$CURRENTUSER

  while [ -z "`dcop | grep $LASTPID`" ]
  do
    sleep 1
  done
  dcop konqueror-${LASTPID} konqueror-mainwindow\#1 openURL $1
  if [ $? -ne 0 ]
  then
    echo ">call failed->using kfmclient"
    dcop konqueror-${LASTPID} MainApplication-Interface quit
    kfmclient exec $1
  fi
}

open_moz()
{
  echo "using mozilla"
  if [ -z "`which mozilla`" ]
  then
    echo "Mozilla binary has to be in \$PATH"
    exit 1
  fi

   echo "checking if Mozilla is running..."
   mozilla -remote "ping()"
   ERRORCODE=$?
   
   if [ "$ERRORCODE" -eq 0 ]
   then
     echo "->Mozilla is running!"
     mozilla -remote "openURL($1)"
   else
     echo "->no instance of Mozilla found!"
     echo "->starting new instance of Mozilla"
     mozilla $1 &
   fi
}

usage()
{
  echo " usage: $0 [URL] k|m"
}

BROWSER=$2

if [ "$#" -lt 2 ]
then
  BROWSER=$DEFAULTBROWSER
fi

if [ "$#" -lt 1 ]
then
  usage
  exit 1
fi



case "$BROWSER" in
  m   ) open_moz $1;;
  k   ) open_konq $1;;
  *   ) usage; exit 1;;
esac

echo "all done"
